<?php



namespace Drupal\custom_locales_comerciales\Controller;



use Symfony\Component\HttpFoundation\JsonResponse;

use Symfony\Component\HttpFoundation\Request;

use Drupal\node\Entity\Node;

use Drupal\file\Entity\File;

use Drupal\taxonomy\Entity\Term;



/**

 * Controlador para la API de Locales Comerciales.

 */

class CustomLocalesComController {



  /**

   * Retorna los locales comerciales en formato JSON.

   *

   * @param \Symfony\Component\HttpFoundation\Request $request

   *   El objeto request.

   *

   * @return \Symfony\Component\HttpFoundation\JsonResponse

   *   La respuesta JSON.

   */

  public function get(Request $request) {

    // Tipos de contenido disponibles.

    $content_types = ['locales_comerciales'];

    

    // Query de contenido.

    $query = \Drupal::entityQuery('node')

      ->condition('type', $content_types, 'IN')

      ->condition('status', 1) // Solo contenido publicado.

      ->accessCheck(TRUE);

    

    $nids = $query->execute();

    

    // Cargar nodos.

    $nodes = Node::loadMultiple($nids);

    $results = [];

    

    foreach ($nodes as $node) {

      // Datos del departamento (taxonomía)

      $departamento_data_id = "";

      $departamento_data_name = "";

      

      // Verificar si el campo existe y tiene un valor

      if ($node->hasField('field_departamento') && !$node->get('field_departamento')->isEmpty()) {

        // Obtener la referencia al término de taxonomía

        $departamento_reference = $node->get('field_departamento')->first();

        

        // Obtener el ID del término

        $departamento_id = $departamento_reference->target_id;

        

        // Cargar el término completo para obtener su nombre

        $departamento_term = \Drupal::entityTypeManager()

          ->getStorage('taxonomy_term')

          ->load($departamento_id);

        

        if ($departamento_term) {

          $departamento_data_id = $departamento_id;

          $departamento_data_name = $departamento_term->getName();

        }

      }



      // Datos del ciudad (taxonomía)

      $ciudad_data_id = "";

      $ciudad_data_name = "";

      

      // Verificar si el campo existe y tiene un valor

      if ($node->hasField('field_ciudad') && !$node->get('field_ciudad')->isEmpty()) {

        // Obtener la referencia al término de taxonomía

        $ciudad_reference = $node->get('field_ciudad')->first();

        

        // Obtener el ID del término

        $ciudad_id = $ciudad_reference->target_id;

        

        // Cargar el término completo para obtener su nombre

        $ciudad_term = \Drupal::entityTypeManager()

          ->getStorage('taxonomy_term')

          ->load($ciudad_id);

        

        if ($ciudad_term) {

          $ciudad_data_id = $ciudad_id;

          $ciudad_data_name = $ciudad_term->getName();

        }

      }



      // Datos del departamento (taxonomía)

      $sector_data_id = "";

      $sector_data_name = "";

      

      // Verificar si el campo existe y tiene un valor

      if ($node->hasField('field_sector') && !$node->get('field_sector')->isEmpty()) {

        // Obtener la referencia al término de taxonomía

        $sector_reference = $node->get('field_sector')->first();

        

        // Obtener el ID del término

        $sector_id = $sector_reference->target_id;

        

        // Cargar el término completo para obtener su nombre

        $sector_term = \Drupal::entityTypeManager()

          ->getStorage('taxonomy_term')

          ->load($sector_id);

        

        if ($sector_term) {

          $sector_data_id = $sector_id;

          $sector_data_name = $sector_term->getName();

        }

      }



      // Datos del estado (taxonomía)

      $estado_data_id = "";

      $estado_data_name = "";

      

      // Verificar si el campo existe y tiene un valor

      if ($node->hasField('field_estados') && !$node->get('field_estados')->isEmpty()) {

        // Obtener la referencia al término de taxonomía

        $estado_reference = $node->get('field_estados')->first();

        

        // Obtener el ID del término

        $estado_id = $estado_reference->target_id;

        

        // Cargar el término completo para obtener su nombre

        $estado_term = \Drupal::entityTypeManager()

          ->getStorage('taxonomy_term')

          ->load($estado_id);

        

        if ($estado_term) {

          $estado_data_id = $estado_id;

          $estado_data_name = $estado_term->getName();

        }

      }

      

      // Obtener el precio

      $precio = '';

      if ($node->hasField('field_precio') && !$node->get('field_precio')->isEmpty()) {

        $precio = $node->get('field_precio')->value;

      }

      

      // Array para almacenar URLs de las imágenes

      $imagenes = [];

      

      // Verificar si el campo de galería existe y tiene valores

      if ($node->hasField('field_galeria_fotos_multimedi') && !$node->get('field_galeria_fotos_multimedi')->isEmpty()) {

        // Recorrer cada párrafo de la galería

        foreach ($node->get('field_galeria_fotos_multimedi') as $paragraph_item) {

          // Cargar la entidad completa del párrafo

          $paragraph = \Drupal::service('entity_type.manager')

            ->getStorage('paragraph')

            ->load($paragraph_item->target_id);

          

          // Si el párrafo se cargó correctamente y tiene un campo de imagen

          if ($paragraph && $paragraph->hasField('field_imagen') && !$paragraph->get('field_imagen')->isEmpty()) {

            // Recorrer todas las imágenes del campo field_imagen

            foreach ($paragraph->get('field_imagen') as $image_field) {

              // Obtener el ID del archivo

              $fid = $image_field->target_id;

              

              // Cargar el archivo

              $file = File::load($fid);

              

              if ($file) {

                // Obtener la URL del archivo usando el servicio adecuado para Drupal 10

                $image_url = \Drupal::service('file_url_generator')->generateAbsoluteString($file->getFileUri());

                

                $imagenes[] = [

                  'url' => $image_url,

                  'alt' => $image_field->alt ?: ''

                ];

              }

            }

          }

        }

      }

      

      // Array para almacenar características del proyecto

      $caracteristicas = [];

      

      // Verificar si el campo de características existe y tiene valores

      if ($node->hasField('field_caracteristicas_del_proyec') && !$node->get('field_caracteristicas_del_proyec')->isEmpty()) {

        // Recorrer cada párrafo de características

        foreach ($node->get('field_caracteristicas_del_proyec') as $paragraph_item) {

          // Cargar la entidad completa del párrafo

          $paragraph = \Drupal::service('entity_type.manager')

            ->getStorage('paragraph')

            ->load($paragraph_item->target_id);

          

          if ($paragraph) {

            $caracteristica = [];

            

            // Obtener el valor de texto

            if ($paragraph->hasField('field_valor') && !$paragraph->get('field_valor')->isEmpty()) {

              $caracteristica['valor'] = $paragraph->get('field_valor')->value;

            } else {

              $caracteristica['valor'] = '';

            }

            

            // Obtener datos del icono (término de taxonomía)

            if ($paragraph->hasField('field_icono') && !$paragraph->get('field_icono')->isEmpty()) {

              $icono_reference = $paragraph->get('field_icono')->first();

              $icono_tid = $icono_reference->target_id;

              

              // Cargar el término de taxonomía

              $icono_term = Term::load($icono_tid);

              

              if ($icono_term) {

                

                // Verificar si el término tiene un campo de imagen

                // Asumiendo que el campo de imagen en el término se llama 'field_icono_imagen'

                // Ajusta este nombre según la estructura de tu taxonomía

                if ($icono_term->hasField('field_icono_caracteristica') && !$icono_term->get('field_icono_caracteristica')->isEmpty()) {

                  $icon_image_field = $icono_term->get('field_icono_caracteristica')->first();

                  $icon_fid = $icon_image_field->target_id;

                  

                  // Cargar el archivo

                  $icon_file = File::load($icon_fid);

                  

                  if ($icon_file) {

                    $icon_url = \Drupal::service('file_url_generator')->generateAbsoluteString($icon_file->getFileUri());

                    $caracteristica['icono'] = $icon_url;

                  }

                }

              }

            }

            

            $caracteristicas[] = $caracteristica;

          }

        }

      }

      // Obtener el precio

      $code_serk = '';

      if ($node->hasField('field_codigo_serk') && !$node->get('field_codigo_serk')->isEmpty()) {

        $code_serk = $node->get('field_codigo_serk')->value;

      }

      // Construir array de resultados

      $results[] = [

        'id' => $node->id(),

        'title' => $node->getTitle(),

        'url' => $node->toUrl()->toString(),

        'codigo_serk' => $code_serk,

        'departamento_data_id' => $departamento_data_id,

        'departamento_data_name' => $departamento_data_name,

        'ciudad_data_id' => $ciudad_data_id,

        'ciudad_data_name' => $ciudad_data_name,

        'sector_data_id' => $sector_data_id,

        'sector_data_name' => $sector_data_name,

        'estado_data_id' => $estado_data_id,

        'estado_data_name' => $estado_data_name,

        'precio' => $precio,

        'imagenes' => $imagenes,

        'caracteristicas' => $caracteristicas,

      ];

    }

    

    // Devolver resultados con metadatos

    return new JsonResponse($results);

  }

}