<?php

namespace Drupal\custom_project_comparator\Controller;

use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Drupal\node\Entity\Node;

class CustomComparatorController {

  public function comparator(Request $request) {
    // Obtener los IDs desde la URL (parámetro 'ids') y convertirlos en un array.
    $ids_param = $request->query->get('ids', '');
    $ids = array_filter(array_map('trim', explode(',', $ids_param)));

    // Tipos de contenido disponibles.
    $allowed_content_types = ['proyectos'];

    // Crear la consulta de contenido.
    $query = \Drupal::entityQuery('node')
      ->condition('type', $allowed_content_types, 'IN')
      ->condition('status', 1) // Solo contenido publicado.
      ->accessCheck(TRUE);

    // Si se pasaron IDs, agregar condición para filtrarlos.
    if (!empty($ids)) {
      $query->condition('nid', $ids, 'IN');
    }

    $nids = $query->execute();

    // Cargar nodos.
    $nodes = Node::loadMultiple($nids);
    $results = [];

    foreach ($nodes as $node) {
      // Inicializar datos para el nodo actual.
      $node_data = [
        'id' => $node->id(),
        'title' => $node->getTitle(),
        'url' => $node->toUrl()->toString(),
        'field_precio' => $node->get('field_precio')->value,
        'field_precio_separacion' => $node->get('field_precio_separacion')->value,
        'field_ciudad' => $node->get('field_ciudad')->entity->getName()
      ];

      // Obtener la URL del campo 'field_imagen_card' (campo de imagen).
      if ($node->hasField('field_imagen_card') && !$node->get('field_imagen_card')->isEmpty()) {
        $image = $node->get('field_imagen_card')->entity;
        if ($image) {
          // Obtener la URI del archivo
          $uri = $image->getFileUri();
          // Convertir la URI en una URL accesible
          $url = \Drupal::service('file_url_generator')->generateAbsoluteString($uri);
          $node_data['field_imagen_card_url'] = $url; // Asignar la URL de la imagen
        }
      }

      // Obtener el campo de tipo Paragraph (field_tipo_aptos_disponibles).
      if ($node->hasField('field_tipo_aptos_disponibles') && !$node->get('field_tipo_aptos_disponibles')->isEmpty()) {
        $paragraphsOne = $node->get('field_tipo_aptos_disponibles')->referencedEntities();
        $paragraph_data_one = [];

        // Recorrer los párrafos asociados.
        foreach ($paragraphsOne as $paragraph) {
          $dataOne = [];
          
          // Acceder a los valores de los campos específicos en el párrafo.
          $fields = [
            'field_titulo_apto',
            'field_precio',
            'field_caracteristicas_del_compar'
          ];

          foreach ($fields as $field_name) {
            // Obtener el valor del campo y añadirlo al array de datos.

            if ($field_name == 'field_caracteristicas_del_compar') {
              if ($paragraph->hasField('field_caracteristicas_del_compar') && !$paragraph->get('field_caracteristicas_del_compar')->isEmpty()) {
                // Acceder a los párrafos referenciados en 'field_caracteristicas_del_apto'.
                $paragraphsAptos = $paragraph->get('field_caracteristicas_del_compar')->referencedEntities();


                $dataOneAptos = [];

                foreach ($paragraphsAptos as $paragraphApto) {

                  $urlImgAlcobas = '';
                  if($paragraphApto->get('field_numero_de_alcobas')->value != ""){
                    $imgsAlcobas = $paragraphApto->get('field_imagenes_alcobas')->entity;
                    if ($imgsAlcobas) {
                      // Obtener la URI del archivo
                      $uri = $imgsAlcobas->getFileUri();
                      // Convertir la URI en una URL accesible
                      $url = \Drupal::service('file_url_generator')->generateAbsoluteString($uri);
                      $urlImgAlcobas = $url; // Asignar la URL de la imagen
                    }
                  }

                  $urlImgBanos = '';
                  if($paragraphApto->get('field_numero_de_banos')->value != ""){
                    $imgsBanos = $paragraphApto->get('field_imagenes_banos')->entity;
                    if ($imgsBanos) {
                      // Obtener la URI del archivo
                      $uriBanos = $imgsBanos->getFileUri();
                      // Convertir la URI en una URL accesible
                      $urlBanos = \Drupal::service('file_url_generator')->generateAbsoluteString($uriBanos);
                      $urlImgBanos = $urlBanos; // Asignar la URL de la imagen
                    }
                  }

                  $urlImgSalaCo = '';
                  if($paragraphApto->get('field_sala_comedor')->value != ""){
                    $imgsSalaCom = $paragraphApto->get('field_imagenes_sala_comedor')->entity;
                    if ($imgsSalaCom) {
                      // Obtener la URI del archivo
                      $uriSalaC = $imgsSalaCom->getFileUri();
                      // Convertir la URI en una URL accesible
                      $urlSalaC = \Drupal::service('file_url_generator')->generateAbsoluteString($uriSalaC);
                      $urlImgSalaCo = $urlSalaC; // Asignar la URL de la imagen
                    }
                  }

                  $urlImgCocina = '';
                  if($paragraphApto->get('field_cocina')->value != ""){
                    $imgsCoci = $paragraphApto->get('field_imagenes_cocina')->entity;
                    if ($imgsCoci) {
                      // Obtener la URI del archivo
                      $uriCoci = $imgsCoci->getFileUri();
                      // Convertir la URI en una URL accesible
                      $urlCoci = \Drupal::service('file_url_generator')->generateAbsoluteString($uriCoci);
                      $urlImgCocina = $urlCoci; // Asignar la URL de la imagen
                    }
                  }

                  $urlImgAreLabInd = '';
                  if($paragraphApto->get('field_area_de_labores_independie')->value != ""){
                    $imgsAreaLabInd = $paragraphApto->get('field_imagenes_area_de_labo')->entity;
                    if ($imgsAreaLabInd) {
                      // Obtener la URI del archivo
                      $uriAreLabInd = $imgsAreaLabInd->getFileUri();
                      // Convertir la URI en una URL accesible
                      $urlArealabInd = \Drupal::service('file_url_generator')->generateAbsoluteString($uriAreLabInd);
                      $urlImgAreLabInd = $urlArealabInd; // Asignar la URL de la imagen
                    }
                  }

                  $urlImgBalcon = '';
                  if($paragraphApto->get('field_balcon')->value != ""){
                    $imgsBalcon = $paragraphApto->get('field_imagenes_balcon')->entity;
                    if ($imgsBalcon) {
                      // Obtener la URI del archivo
                      $uriBalcon = $imgsBalcon->getFileUri();
                      // Convertir la URI en una URL accesible
                      $urlBalcon = \Drupal::service('file_url_generator')->generateAbsoluteString($uriBalcon);
                      $urlImgBalcon = $urlBalcon; // Asignar la URL de la imagen
                    }
                  }

                  $dataOneAptos[] = [
                    'field_area_construida' => trim($paragraphApto->get('field_area_construida')->value),
                    'field_area_privada' => trim($paragraphApto->get('field_area_privada')->value),
                    'field_numero_de_alcobas' => trim($paragraphApto->get('field_numero_de_alcobas')->value),
                    'field_imagenes_alcobas' => $urlImgAlcobas,
                    'field_numero_de_banos' => trim($paragraphApto->get('field_numero_de_banos')->value),
                    'field_imagenes_banos' => $urlImgBanos,
                    'field_sala_comedor' => trim($paragraphApto->get('field_sala_comedor')->value),
                    'field_imagenes_sala_comedor' => $urlImgSalaCo,
                    'field_cocina' => trim($paragraphApto->get('field_cocina')->value),
                    'field_imagenes_cocina' => $urlImgCocina,
                    'field_area_de_labores_independie' => trim($paragraphApto->get('field_area_de_labores_independie')->value),
                    'field_imagenes_area_de_labo' => $urlImgAreLabInd,
                    'field_balcon' => trim($paragraphApto->get('field_balcon')->value),
                    'field_imagenes_balcon' => $urlImgBalcon
                  ];
                }

                $dataOne[$field_name] = $dataOneAptos;
              }
            }

            $field_value = $paragraph->get($field_name)->value ?? null;
            if ($field_value !== null) {
              $dataOne[$field_name] = $field_value;
            }
          }

          $paragraph_data_one[] = $dataOne;
        }

        // Agregar los párrafos al nodo actual.
        $node_data['tipo_aptos_disponibles'] = $paragraph_data_one;
      }

      // Obtener el campo de tipo Paragraph (field_el_proyecto_contiene).
      if ($node->hasField('field_el_proyecto_contiene') && !$node->get('field_el_proyecto_contiene')->isEmpty()) {
        $paragraphs = $node->get('field_el_proyecto_contiene')->referencedEntities();
        $paragraph_data = [];

        // Recorrer los párrafos asociados.
        foreach ($paragraphs as $paragraph) {
          $data = [];
          
          // Acceder a los valores de los campos específicos en el párrafo.
          $fields = [
            'field_cancha_en_cesped_natural',
            'field_cancha_multiple',
            'field_coworking',
            'field_gimnasio',
            'field_gimnasio_biosaludable',
            'field_kiosko',
            'field_oficina_de_administracion',
            'field_piscina_para_adultos',
            'field_piscina_para_ninos',
            'field_porteria',
            'field_salas_premium',
            'field_sala_de_tv',
            'field_salon_de_juegos',
            'field_salon_multiple',
            'field_sport_bar',
            'field_zonas_verdes',
            'field_zona_bbq',
            'field_zona_de_juegos_infantiles',
          ];

          foreach ($fields as $field_name) {
            // Obtener el valor del campo y añadirlo al array de datos.
            $field_value = $paragraph->get($field_name)->value ?? null;
            if ($field_value !== null) {
              $data[$field_name] = $field_value;
            }
          }

          $paragraph_data[] = $data;
        }

        // Agregar los párrafos al nodo actual.
        $node_data['el_proyecto_contiene'] = $paragraph_data;
      }

      $results[] = $node_data;
    }

    // Devolver resultados con metadatos de paginación.
    return new JsonResponse([
      'results' => $results,
    ]);
  }
}
