<?php

namespace Drupal\custom_project_work_progress\Controller;

use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Drupal\node\Entity\Node;

class CustomWorkProgressController {

  public function workProgress(Request $request) {
    // Tipos de contenido disponibles.
    $allowedContentTypes = ['avances_de_obras'];

    // Obtener el ID del proyecto asociado desde los parámetros de la solicitud.
    $projectId = $request->query->get('project_id');

    // Crear la consulta de contenido.
    $query = \Drupal::entityQuery('node')
      ->condition('type', $allowedContentTypes, 'IN')
      ->condition('status', 1) // Solo contenido publicado.
      ->accessCheck(TRUE);

    // Agregar condición para filtrar por project_id si está presente.
    if (!empty($projectId)) {
      $query->condition('field_proyecto_asociado', $projectId);
    }

    // Ejecutar la consulta para obtener los IDs de los nodos.
    $nids = $query->execute();

    // Cargar nodos.
    $nodes = Node::loadMultiple($nids);
    $results = array();

    foreach ($nodes as $node) {
      // Inicializar datos para el nodo actual.
      $nodeData = [
        'id' => $node->id(),
        'title' => $node->getTitle(),
        'field_departament' => $node->hasField('field_departamento') && $node->get('field_departamento')->entity 
          ? $node->get('field_departamento')->entity->getName() 
          : null,
        'field_city_id' => $node->hasField('field_ciudad') && $node->get('field_ciudad')->entity 
          ? $node->get('field_ciudad')->entity->id() 
          : null,
        'field_city_name' => $node->hasField('field_ciudad') && $node->get('field_ciudad')->entity 
          ? $node->get('field_ciudad')->entity->getName() 
          : null,
        'field_status_id' => $node->hasField('field_estados') && $node->get('field_estados')->entity 
          ? $node->get('field_estados')->entity->id() 
          : null,
        'field_status_name' => $node->hasField('field_estados') && $node->get('field_estados')->entity 
          ? $node->get('field_estados')->entity->getName() 
          : null,
      ];

      // Obtener la URL del campo 'field_imagen_card' (campo de imagen).
      if ($node->hasField('field_imagen_card') && !$node->get('field_imagen_card')->isEmpty()) {
        $image = $node->get('field_imagen_card')->entity;
        if ($image) {
          $uri = $image->getFileUri();
          $url = \Drupal::service('file_url_generator')->generateAbsoluteString($uri);
          $nodeData['field_imagen_card_url'] = $url;
        }
      }

      // Manejar los párrafos (igual que antes).
      if ($node->hasField('field_avances_de_obra') && !$node->get('field_avances_de_obra')->isEmpty()) {
        $paragraphsOne = $node->get('field_avances_de_obra')->referencedEntities();
        $paragraphDataOne = array();

        foreach ($paragraphsOne as $paragraph) {
          $urlsImg = array();

          if ($paragraph->hasField('field_imagenes_de_avance_de_obra') && !$paragraph->get('field_imagenes_de_avance_de_obra')->isEmpty()) {
            $images = $paragraph->get('field_imagenes_de_avance_de_obra')->referencedEntities();

            foreach ($images as $image) {
              $uriImg = $image->getFileUri();
              $urlImg = \Drupal::service('file_url_generator')->generateAbsoluteString($uriImg);
              $urlsImg[] = $urlImg;
            }
          }

          $dataOne = [
            'field_fecha' => $paragraph->get('field_fecha')->value ?? null,
            'field_imgs' => $urlsImg,
          ];

          $paragraphDataOne[] = $dataOne;
        }

        $nodeData['field_work_progress'] = $paragraphDataOne;
      }

      $results[] = $nodeData;
    }

    // Devolver resultados con metadatos de paginación.
    return new JsonResponse($results);
  }


}
