document.addEventListener("DOMContentLoaded", function() {

  // Constantes
  const searchInput = document.getElementById('searchInput');
  const searchButton = document.getElementById('searchButton');
  const recentSearches = document.getElementById('resultSearchRecien');
  const resultSugeri = document.getElementById('resultSugeri');
  const recentSearchList = document.getElementById('resultSearchRecienListItems');

  // Clave para almacenar las búsquedas en LocalStorage
  const SEARCH_KEY = 'recent_searches';

  // Función para guardar la búsqueda en LocalStorage
  function saveSearch(query) {
    if (!query) return;

    // Obtener búsquedas existentes
    let searches = JSON.parse(localStorage.getItem(SEARCH_KEY)) || [];

    // Eliminar duplicados y agregar al principio
    searches = [query, ...searches.filter(item => item !== query)];

    // Limitar a 5 búsquedas recientes
    if (searches.length > 5) {
      searches = searches.slice(0, 5);
    }

    // Guardar en LocalStorage
    localStorage.setItem(SEARCH_KEY, JSON.stringify(searches));

    // Redirigir a una página específica
    window.location.href = `/constructora-bolivar-v2/buscador?q=${encodeURIComponent(query)}`;

  }

  // Función para cargar búsquedas recientes
  function loadRecentSearches() {
    const searches = JSON.parse(localStorage.getItem(SEARCH_KEY)) || [];

    // Limpiar la lista
    recentSearchList.innerHTML = '';

    if( searches.length > 0 ){

      // Agregar búsquedas a la lista
      searches.forEach((search, index) => {
        const listItem = document.createElement('li');

        listItem.innerHTML = `
          <div class="wrapperContentReci">
            <div>
              <img src="/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-reload-quit.svg" width="18" height="18" alt="${search}">
              <h4>${search}</h4>
            </div>
            <a class="remove-search" data-index="${index}">
              <span>Quitar</span>
            </a>
          </div>
        `;

        listItem.addEventListener('click', (e) => {
          
          // Evitar que el clic en "Quitar" también seleccione la búsqueda
          if (!e.target.closest('.remove-search')) {
            $('#searchInput').val(search);
            $('#resultSearchRecien').removeClass('show');
          }

        });
        recentSearchList.appendChild(listItem);
      });

    }else{

      const listItemNullOne = document.createElement('li');

      listItemNullOne.innerHTML = `
        <div class="wrapperContentReci">
          <div>
            <h4>No se encontraron resultados</h4>
          </div>
        </div>
      `;
      recentSearchList.appendChild(listItemNullOne);

    }
  }

  // Manejar la eliminación de búsquedas
  recentSearchList.addEventListener('click', (e) => {
    const removeButton = e.target.closest('.remove-search');
    if (removeButton) {
      e.preventDefault();

      // Obtener el índice de la búsqueda a eliminar
      const indexToRemove = removeButton.dataset.index;

      // Eliminar del arreglo de LocalStorage
      let searches = JSON.parse(localStorage.getItem(SEARCH_KEY)) || [];
      searches.splice(indexToRemove, 1);
      localStorage.setItem(SEARCH_KEY, JSON.stringify(searches));

      // Recargar la lista de búsquedas
      loadRecentSearches();
    }
  });

  // Evento para guardar la búsqueda al hacer clic en el botón
  searchButton.addEventListener('click', () => {
    const query = searchInput.value.trim();
    if (query) {
      saveSearch(query);
      loadRecentSearches();
    }
  });

  // Evento para mostrar búsquedas recientes al enfocar el input
  searchInput.addEventListener('focus', () => {
    let searchExis = searchInput.value;
    if(searchExis.length < 3){
      loadRecentSearches();
      $('#resultSearchRecien').addClass('show');
    }
  });

  // Evento para ocultar las búsquedas recientes al hacer clic fuera del input
  document.addEventListener('click', (e) => {
    if (!recentSearches.contains(e.target) && e.target !== searchInput) {
      $('#resultSearchRecien').removeClass('show');
    }
  });

  // Evento para ocultar las búsquedas recientes al hacer clic fuera del input
  document.addEventListener('click', (e) => {
    if (!resultSugeri.contains(e.target) && e.target !== searchInput) {
      $('#resultSugeri').removeClass('show');
    }
  });





  setTimeout(() => {
  // Eliminar el texto "Con la tecnología de"
    const gadget = document.querySelector('.goog-te-gadget');
    if (gadget) {
      const nodes = gadget.childNodes;
      nodes.forEach(node => {
        if (node.nodeType === 3 && node.nodeValue.includes('Con la tecnología de ')) {
          node.remove();
        }
      });
    }
  }, 500);

});

function googleTranslateElementInit() {
  new google.translate.TranslateElement({pageLanguage: 'es', includedLanguages: 'en,fr,es', layout: google.translate.TranslateElement.InlineLayout.VERTICAL}, 'google_translate_element');
}

async function funcFilter(e){
  let valueFilter = e.value;
  const wrapperList = document.querySelector('#resultSugeri .wrapperListResultItem');

  if(valueFilter.length >= 3){

    if( $('#resultSearchRecien').hasClass('show') ){
      $('#resultSearchRecien').removeClass('show');
    }

    try {
      const response = await fetch(`/constructora-bolivar-v2/api/buscador?q=` + valueFilter + `&type=proyectos&page=0&items_per_page=5`); // Cambia la URL a tu endpoint
      const data = await response.json();
      
      // Limpiar los resultados previos
      wrapperList.innerHTML = '';
      if (data.results.length > 0) {
        data.results.forEach(item => {
          const listItem = document.createElement('li');
          listItem.innerHTML = `
            <a href="${item.url}" class="itemResult">
              <h4>${item.title}</h4>
              <img src="/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-upper-right-arrow.svg" width="18" height="18" alt="${item.title}">
            </a>
          `;
          wrapperList.appendChild(listItem);
        });

        $('#resultSugeri').addClass('show'); // Mostrar los resultados
      } else {
        const listItemTwo = document.createElement('li');
          listItemTwo.innerHTML = `
            <a href="javascript:void(0);" style="cursor: initial;" class="itemResult">
              <h4>No se encontraron resultados</h4>
            </a>
          `;
          wrapperList.appendChild(listItemTwo);
        $('#resultSugeri').addClass('show');
      }

    } catch (error) {
      console.error('Error al realizar la búsqueda:', error);
    }
  }else{
    $('#resultSugeri').removeClass('show');
    if( !$('#resultSearchRecien').hasClass('show') ){
      $('#resultSearchRecien').addClass('show');
    }
  }
}