// Variable global para almacenar las ubicaciones
let globalLocations = [];
// Variable global para almacenar los marcadores
let markers = [];

document.addEventListener('DOMContentLoaded', function () {

  getCitysTaxonomies();

  getSectorsTaxonomies();

  initSearchSalaVentas('','all','all');



});



$(document).on('click','.btnReturnSala',  function(e){

  e.preventDefault();

  $('#wrapperSingleDetail').hide();

});



$(document).on('click','#searchButton',  function(e){

  e.preventDefault();

  searchFiler();

});



function searchFiler(){

  let searchInputSala = $('#searchInputSala').val();

  let filterCitySala = $('#filterCitySala').val() || 'all';

  let filterSectorSala = $('#filterSectorSala').val() || 'all';


  if(filterCitySala != "all"){

    getSectorsTaxonomies();

  }



  initSearchSalaVentas(searchInputSala,filterCitySala,filterSectorSala);

}



async function initSearchSalaVentas(text, city, sector) {

  try {

    // Limpiamos las ubicaciones anteriores
    globalLocations = [];
    markers = [];

    const response = await fetch(`/constructora-bolivar-v2/api/sala-de-ventas/`+city+`/`+sector);
    const data = await response.json();

    

    // Filtrar los datos según el texto de búsqueda si no está vacío

    const filteredData = text.trim() === '' ? data : data.filter(item => 

      item.title.toLowerCase().includes(text.toLowerCase())

    );

    

    $('.listSalasVenta').empty();

    

    // Si no hay resultados después del filtrado

    if (filteredData.length === 0) {

      $('.listSalasVenta').append(`

        <div class="noResults">

          <p>No se encontraron resultados</p>

        </div>

      `);

      return;

    }

    

    filteredData.forEach((item, index) => {

      const firstImage = item.field_imagen_card.split(',')[0].trim();

      globalLocations.push({ 
        id: index,
        lat: parseFloat(item.field_ubicacion_latitud), 
        lng: parseFloat(item.field_ubicacion_longitud), 
        label: item.title 
      });

      $('.listSalasVenta').append(`

        <div class="itemSalasVenta" data-index="${index}" data-title="${item.title}" data-field_imagen_card="${firstImage}" 
        data-field_direccion="${item.field_direccion}" 
        data-field_horarios="${item.field_horarios}" 
        data-field_telefono="${item.field_telefono}"
        data-field_url_waze="${item.field_url_waze}"
        data-field_url_googlemaps="${item.field_url_google_maps}" >

          <div class="itemSubSalasVenta">

            <img src="${firstImage}" width="60" height="60" alt="">

            <div>

              <h3>${item.title}</h3>

              <p>${item.field_direccion}</p>

            </div>

          </div>

          <a href="#">Ver info <span class="icoRight2"></span></a>

        </div>

      `);

    });

    // Añadir evento de clic a los elementos de la lista
    $(document).on('click','.itemSalasVenta',  function(e){
      console.log( $(this).attr('data-field_imagen_card') );
      // Evitar el comportamiento predeterminado si se hace clic en el enlace
      if ($(e.target).hasClass('viewMapLink') || $(e.target).parents('.viewMapLink').length) {
        e.preventDefault();
      }

      $('#wrapperHtmlSingleSala').empty();
      $('#wrapperSingleDetail').show();

      let title = $(this).attr('data-title');
      let field_imagen_card = $(this).attr('data-field_imagen_card');
      let field_direccion = $(this).attr('data-field_direccion');
      let field_horarios = $(this).attr('data-field_horarios');
      let field_telefono = $(this).attr('data-field_telefono');
      let url_waze = $(this).attr('data-field_url_waze');
      let url_googlemaps = $(this).attr('data-field_url_googlemaps');

      let url_waze_html = "";
      let url_googlemaps_html = "";
      
      if(url_waze !=""){
        let url_waze_html = `<a href="`+url_waze+`" target="_blank">Ir con Waze</a>`;
      }

      if(url_googlemaps !=""){
        let url_googlemaps_html = `<a href="`+url_googlemaps+`" target="_blank">Ir con Google Maps</a>`;
      }

      $('#wrapperHtmlSingleSala').append(`
        <img src="`+field_imagen_card+`" width="100%" height="134" alt="`+title+`">
        <div class="separator-10"></div>
        <div class="px-4">
          <h4>`+title+`</h4>
          <div class="separator-5"></div>
          <p><strong>Dirección:</strong> `+field_direccion+`</p>
          <p><strong>Teléfono:</strong> `+field_telefono+`</p>
          <p><strong>Horarios:</strong> `+field_horarios+`</p>
          <div class="separator-15"></div>
          <div class="wrapperGroupUbiLinks">
            `+url_waze_html+`
            `+url_googlemaps_html+`
          </div>
        </div>
      `);
      
      const index = $(this).data('index');
      focusMapMarker(index);
    });

    // Después de cargar los datos, inicializamos el mapa
    initMap();

  } catch (error) {
    $('.listSalasVenta').empty();

    $('.listSalasVenta').append(`

      <div class="errorMessage">

        <p>Ocurrió un error al buscar las salas de venta</p>

      </div>

    `);

  }

}

// Función para enfocar un marcador específico
function focusMapMarker(index) {
  // Encontrar el marcador correspondiente
  const markerInfo = markers.find(m => m.id === index);
  
  if (markerInfo) {
    // Centrar el mapa en el marcador
    markerInfo.map.setCenter({
      lat: globalLocations[index].lat,
      lng: globalLocations[index].lng
    });
    
    // Hacer zoom al marcador
    markerInfo.map.setZoom(14);
    
    // Opcional: animar el marcador o hacerlo destacar
    // Si estás usando marcadores avanzados, puedes agregar una clase CSS para destacarlo
    // o cambiar temporalmente su apariencia
    
    // También puedes hacer scroll hasta el mapa si está fuera de la vista
    // $('html, body').animate({
    //   scrollTop: $("#mapSalaVentas").offset().top - 100
    // }, 500);
  }
}

async function getCitysTaxonomies() {

  const response = await fetch('/constructora-bolivar-v2/api/filtro/ciudades');

  const cityData = await response.json();

  

  // Crear un objeto para rastrear ciudades únicas por tid

  const uniqueCities = {};

  

  // Llenar el objeto con ciudades únicas

  cityData.forEach(item => {

    uniqueCities[item.tid] = item.name;

  });

  

  // Agregar las opciones únicas al select

  Object.entries(uniqueCities).forEach(([tid, name]) => {

    $('#filterCitySala').append(`

      <option value="${tid}">${name}</option>

    `);

  });

}



async function getSectorsTaxonomies() {

  let cityId = $('#filterCitySala').val() || '';
  let sectorId = $('#filterSectorSala').val() || '';

  const response = await fetch('/constructora-bolivar-v2/api/filtro/sectores');

  const sectorData = await response.json();

  

  // Limpiar opciones anteriores

  $('#filterSectorSala').empty();

  

  // Agregar opción por defecto

  $('#filterSectorSala').append(`<option value="all">Sectores</option>`);

  

  // Filtrar sectores por field_ciudad y eliminar duplicados

  const uniqueSectors = {};

  

  sectorData.forEach(item => {

    if (cityId !='' && item.field_ciudad === cityId) {

      uniqueSectors[item.tid] = item.name;

    }

  });

  

  // Agregar las opciones únicas filtradas al select

  Object.entries(uniqueSectors).forEach(([tid, name]) => {
    let currentSelected = '';
    if(sectorId == tid){
      currentSelected = 'selected';
    }

    $('#filterSectorSala').append(`

      <option `+currentSelected+` value="${tid}">${name}</option>

    `);

  });

}



function initMap() {

  // Crear el mapa centrado en la primera ubicación
  const map = new google.maps.Map(document.getElementById("mapSalaVentas"), {

    zoom: 14, // Ajustado para mostrar múltiples marcadores

    center: { lat: 4.6482784, lng: -74.2726218 },

    mapId: "DEMO_MAP_ID", 

  });

  

  // Crear marcadores para cada ubicación

  globalLocations.forEach(location => {

    // Crear el elemento de imagen como nodo DOM

    const imgElement = document.createElement("img");

    imgElement.src = "/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/internaProyecto/icon-location.svg";

    imgElement.alt = location.label;

    imgElement.style.width = "70px";

    imgElement.style.height = "70px";

    

    // Crear el marcador avanzado

    const marker = new google.maps.marker.AdvancedMarkerElement({

      map: map,

      position: { lat: location.lat, lng: location.lng },

      title: location.label,

      content: imgElement

    });

    // Guardar referencia al marcador
    markers.push({
      id: location.id,
      marker: marker,
      map: map
    });

  });

  

  // Ajustar el zoom para mostrar todos los marcadores (opcional)
  const bounds = new google.maps.LatLngBounds();

  globalLocations.forEach(location => {

    bounds.extend({ lat: location.lat, lng: location.lng });

  });

  map.fitBounds(bounds);

}