new Vue({

    delimiters: ["${", "}"],

    el: '#app',

    data() {

      return {

        valorUsd: '',

        valorEur: '',

        currency: 'COP',

        currencyIcon: '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg',

        currencySymbols: {

            COP: '$',   // Símbolo para COP

            USD: '', // Símbolo para USD

            EUR: '€',   // Símbolo para EUR

        },

        searchQuery: '', // Almacena la búsqueda actual

        activeTab: 'page', // Pestaña activa por defecto

        pagination: {

          proyectos: {

            currentPage: 1,

            totalPages: 1,

            results: []

          },

          page: {

            currentPage: 1,

            totalPages: 1,

            results: []

          }

        }

      };

    },

    computed: {

      exchangeRates() {

        return {

            COP: 1,

            USD: this.valorUsd,

            EUR: this.valorEur

        };

      }

    },

    methods: {

      async fetchResults(type) {

        try {

            const page = this.pagination[type].currentPage - 1; // API usa base 0 para la paginación

            const response = await fetch(`/constructora-bolivar-v2/api/buscador?q=${this.searchQuery}&type=${type}&page=${page}&items_per_page=10`);

            const data = await response.json();

            // Actualizar los datos de paginación y resultados

            this.pagination[type].results = data.results || [];

            this.pagination[type].totalPages = data.pagination.total_pages || 1; // Ajusta según tu API



            // Si hay resultados en ambas pestañas, verifica la activa

            if (this.pagination.page.results.length > 0 && this.pagination.proyectos.results.length > 0) {

              this.activeTab = this.activeTab || 'page'; // Mantener la pestaña activa previa

            } else if (this.pagination.page.results.length > 0) {

              this.activeTab = 'page';

            } else if (this.pagination.proyectos.results.length > 0) {

              this.activeTab = 'proyectos';

            }

        } catch (error) {

            console.error(`Error al obtener los resultados de ${type}:`, error);

        }

      },

      changePage(type, page) {

          if (page > 0 && page <= this.pagination[type].totalPages) {

              this.pagination[type].currentPage = page;

              this.fetchResults(type); // Recargar los datos para el tipo específico

          }

      },

      nextPage(type) {

          this.changePage(type, this.pagination[type].currentPage + 1);

      },

      prevPage(type) {

          this.changePage(type, this.pagination[type].currentPage - 1);

      },

      convertCurrency(price) {

        // Convertir el precio a la moneda seleccionada

        if (this.currency === 'COP') {

            return (price); // Precio en COP

        } else if (this.currency === 'USD') {

            return (price * this.exchangeRates.USD).toFixed(0); // Convertir a USD

        } else if (this.currency === 'EUR') {

            return (price * this.exchangeRates.EUR).toFixed(0); // Convertir a EUR

        }

      },

      changeCurrency(selectedCurrency) {

        this.currency = selectedCurrency; // Cambiar la moneda



        // Actualizar el icono de la moneda

        if (selectedCurrency === 'COP') {

            this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg';

        } else if (selectedCurrency === 'USD') {

            this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-usd.svg';

        } else if (selectedCurrency === 'EUR') {

            this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-eur.svg';

        }

      },

      async getTrm() {

        const response = await fetch('/constructora-bolivar-v2/api/trm');

        const datrm = await response.json();

        this.valorUsd = datrm[0].field_valor;

        this.valorEur = datrm[1].field_valor;

      },

    },

    filters: {

      formatPrice(value) {

        //formatear precios

        let val = (value / 1).toFixed(0).replace(".", ",");

        return val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");

      },

    },

    created() {

      const params = new URLSearchParams(window.location.search);

      const searchParam = params.get('q');

      if (searchParam) {

        this.searchQuery = searchParam; // Asignar el valor inicial

        this.fetchResults('page'); // Cargar páginas

        this.fetchResults('proyectos');    // Cargar proyectos

      }

    },

});