new Vue({

    delimiters: ["${", "}"],

    el: '#app',

    data() {

        return {

            isShow: false,

            items: [],

            valorUsd: '',

            valorEur: '',

            currentPage: 1,

            itemsPerPage: 9,

            currency: 'COP',

            currencyIcon: '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg',

            currencySymbols: {

                COP: '$',   // Símbolo para COP

                USD: '', // Símbolo para USD

                EUR: '€',   // Símbolo para EUR

            },

            searchNameProject: '',// Término de búsqueda ingresado por el usuario

            appliedSearchQuery: '', // Término aplicado al hacer clic en el botón

            citysTaxo: '', // Filtro de ciudad

            sectorsTaxo: '', // Filtro de sector

            typeVivienTaxo: '', // Filtro de tipo de vivienda

            statusTaxo: '', // Filtro de estado

            listFilterCitys: [],

            listFilterTypeVivi: [],

            listFilterStatus: [],

            listFilterSectors: [],

            selectedSectors: [] // Sectores seleccionados

        };

    },

    computed: {

     filteredItems() {

        const searchQuery = this.appliedSearchQuery.toLowerCase(); // Convertir a minúsculas para búsqueda insensible a mayúsculas



        // Filtrar items según ciudad, tipo de vivienda y estado

        const filtered = this.items.filter(item => {



            const matchesCiudad = this.citysTaxo === '' || item.field_city_id === this.citysTaxo; // Ajusta 'ciudad' según tu estructura de datos

            const matchesEstado = this.statusTaxo === '' || item.field_status_id === this.statusTaxo; // Ajusta 'estado'

            const matchesSearch = searchQuery === '' || item.title.toLowerCase().includes(searchQuery);



            return matchesCiudad && matchesEstado && matchesSearch;

        });


        const start = (this.currentPage - 1) * this.itemsPerPage;

        return filtered.slice(start, start + this.itemsPerPage);

      },

      totalPages() {

        const searchQuery = this.appliedSearchQuery.toLowerCase(); // Convertir a minúsculas para búsqueda insensible a mayúsculas



        const filteredCount = this.items.filter(item => {

            const matchesCiudad = this.citysTaxo === '' || item.field_city_id === this.citysTaxo; // Ajusta 'ciudad'

            const matchesEstado = this.statusTaxo === '' || item.field_status_id === this.statusTaxo; // Ajusta 'estado'

            const matchesSearch = searchQuery === '' || item.title.toLowerCase().includes(searchQuery);



            return matchesCiudad && matchesEstado && matchesSearch;

        }).length;



        return Math.ceil(filteredCount / this.itemsPerPage);

      },

      exchangeRates() {

        return {

            COP: 1,

            USD: this.valorUsd,

            EUR: this.valorEur

        };

      },

      // Filtros activos, generando etiquetas <a>

      activeFilters() {

        let filters = [];



        // Filtro de Nombre

        if (this.appliedSearchQuery !== '') {

          filters.push({

              label: `Búsqueda: ${this.appliedSearchQuery}`, // Muestra el término de búsqueda

              type: 'search',

              value: this.appliedSearchQuery // Guarda el valor del término aplicado

          });

        }



        // Filtro de Ciudad

        if (this.citysTaxo !== '') {

            const city = this.listFilterCitys.find(city => city.tid === this.citysTaxo);

            if (city) {

                filters.push({

                    label: city.name,

                    type: 'city',

                    value: this.citysTaxo

                });

            }

        }

        // Filtro de Estado

        if (this.statusTaxo !== '') {

            const status = this.listFilterStatus.find(status => status.tid === this.statusTaxo);

            if (status) {

                filters.push({

                    label: status.name,

                    type: 'status',

                    value: this.statusTaxo

                });

            }

        }

        return filters;

      }

    },

    methods: {

        applySearch() {

          this.appliedSearchQuery = this.searchNameProject;

          this.currentPage = 1; // Restablece a la primera página

          // Obtenemos la instancia del offcanvas
          const offcanvasElement = document.getElementById('offcanvasBottom');
          if(offcanvasElement){
            // Ocultamos el offcanvas
            const offcanvasInstance = bootstrap.Offcanvas.getInstance(offcanvasElement);
            offcanvasInstance.hide();
          }

        },

        toggleShow(index) {

          // Alterna el estado de visibilidad para el filtro de la ciudad correspondiente

          this.listFilterCitys[index].isShow = !this.listFilterCitys[index].isShow;

        },

        clearFiltersCitySectors() {

          // Restablece todos los filtros a sus valores iniciales

          this.sectorsTaxo = '';

          this.selectedSectors = [];



          // Opcional: actualiza los datos

          this.fetchData();

        },

        // Eliminar un filtro específico

        removeFilter(filter) {

          if (filter.type === 'city') {

              this.citysTaxo = '';

          } else if (filter.type === 'status') {

              this.statusTaxo = '';

          } else if (filter.type === 'search') {

              this.searchNameProject = '';

              this.appliedSearchQuery = '';

          }





          // Ejecutar la búsqueda con los filtros actualizados

          this.fetchData();

        },

        removeFilterAll(){

          this.selectedSectors = [];



          this.citysTaxo = '';

          this.statusTaxo = '';



          this.searchNameProject = '';

          this.appliedSearchQuery = '';



          // Ejecutar la búsqueda con los filtros actualizados

          this.fetchData();

        },

        async fetchData() {
            this.currentPage = 1;
            const response = await fetch(`/constructora-bolivar-v2/api/avance-de-obra`); // Cambia la URL a tu endpoint

            this.items = await response.json();

            // Filtrar solo los campos id y field_work_progress
            const processedData = this.items.map(item => ({
              id: item.id,
              field_work_progress: item.field_work_progress
            }));

            // Guardar en localStorage como JSON
            localStorage.setItem('workProgressData', JSON.stringify(processedData));

            // Obtenemos la instancia del offcanvas
            const offcanvasElement = document.getElementById('offcanvasBottom');
            if(offcanvasElement){
              // Ocultamos el offcanvas
              const offcanvasInstance = bootstrap.Offcanvas.getInstance(offcanvasElement);
              offcanvasInstance.hide();
            }
        },

        nextPage() {

            if (this.currentPage < this.totalPages) {

                this.currentPage++;

            }

        },

        prevPage() {

            if (this.currentPage > 1) {

                this.currentPage--;

            }

        },

        setPage(page) {

            this.currentPage = page;

        },

        convertCurrency(price) {

            // Convertir el precio a la moneda seleccionada

            if (this.currency === 'COP') {

                return (price); // Precio en COP

            } else if (this.currency === 'USD') {

                return (price * this.exchangeRates.USD).toFixed(0); // Convertir a USD

            } else if (this.currency === 'EUR') {

                return (price * this.exchangeRates.EUR).toFixed(0); // Convertir a EUR

            }

        },

        changeCurrency(selectedCurrency) {

            this.currency = selectedCurrency; // Cambiar la moneda



            // Actualizar el icono de la moneda

            if (selectedCurrency === 'COP') {

                this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg';

            } else if (selectedCurrency === 'USD') {

                this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-usd.svg';

            } else if (selectedCurrency === 'EUR') {

                this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-eur.svg';

            }

        },

        // Filtra los sectores por ciudad

        getSectoresByCiudad(tidCiudad) {

          return this.listFilterSectors.filter(sector => sector.field_ciudad === tidCiudad);

        },

        // Marca o desmarca todos los sectores de una ciudad

        toggleAllSectors(tidCiudad) {

          const sectoresCiudad = this.getSectoresByCiudad(tidCiudad).map(sector => sector.tid);



          // Verifica si todos los sectores ya están seleccionados

          const allSelected = sectoresCiudad.every(tid => this.selectedSectors.includes(tid));



          if (allSelected) {

            // Si todos están seleccionados, los desmarca

            this.selectedSectors = this.selectedSectors.filter(tid => !sectoresCiudad.includes(tid));

          } else {

            // Si no todos están seleccionados, los marca

            this.selectedSectors = [

              ...this.selectedSectors,

              ...sectoresCiudad.filter(tid => !this.selectedSectors.includes(tid))

            ];

          }

        },

        async getTrm() {

          const response = await fetch('/constructora-bolivar-v2/api/trm');

          const datrm = await response.json();

          this.valorUsd = datrm[0].field_valor;

          this.valorEur = datrm[1].field_valor;

        },

        async getStatusTaxonomies() {

          const response = await fetch('/constructora-bolivar-v2/api/filtro/estados');

          this.listFilterStatus = await response.json();

        },

        async getCitysTaxonomies() {

          const response = await fetch('/constructora-bolivar-v2/api/filtro/ciudades');

          const cityData = await response.json();

        

          // Eliminar las ciudades duplicadas basándose en el nombre

          const uniqueCityData = cityData.filter((value, index, self) => 

            index === self.findIndex((t) => (

              t.name === value.name

            ))

          );

        

          // Añadimos la propiedad 'isShow' a cada ciudad que recibimos del servicio

          this.listFilterCitys = uniqueCityData.map(city => ({

            ...city,

            isShow: false, // Inicializamos todos los filtros como ocultos

          }));

        }



    },

    filters: {

      formatPrice(value) {

        //formatear precios

        let val = (value / 1).toFixed(0).replace(".", ",");

        return val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");

      },

    },

    created() {

      this.getTrm();

      this.getStatusTaxonomies();

      this.getCitysTaxonomies();

      this.fetchData();

    },

});