new Vue({

  delimiters: ["${", "}"],



  el: "#app",



  data() {

    return {

      isShow: false,

      items: [],

      valorUsd: "",

      valorEur: "",

      currentPage: 1,

      itemsPerPage: 9,

      currency: "COP",

      currencyIcon: "/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg",

      currencySymbols: {

        COP: "$", // Símbolo para COP

        USD: "", // Símbolo para USD

        EUR: "€", // Símbolo para EUR

      },

      searchNameProject: "", // Término de búsqueda ingresado por el usuario

      appliedSearchQuery: "", // Término aplicado al hacer clic en el botón

      categoryTaxo: "all", // Filtro de categori

      sortOrder: "", // Added for sorting

      selectedSectors: [], // Sectores seleccionados,

      listActuLasts: [],

      listNovedaLasts: [],

      listNotePuedesLasts: [],

      listDestacaLasts: [],

      listAriclesInteres: [],

      listAriclesRecient : [],

      categoryTaxoArticle: "",

      nodeIdArticle: ""

    };

  },



  computed: {

    filteredItems() {

      let filtered = this.items;



      // Filter by category

      if (this.categoryTaxo !== "all") {

        filtered = filtered.filter(item => 

          item.field_categoria_del_articulo_1 === this.categoryTaxo

        );

      }



      // Filter by search query

      if (this.appliedSearchQuery) {

        const searchQuery = this.appliedSearchQuery.toLowerCase();

        filtered = filtered.filter(item => 

          item.title.toLowerCase().includes(searchQuery)

        );

      }



      // Ordenar según la fecha de creación

      if (this.sortOrder === 'newest') {

        filtered.sort((a, b) => {

          const dateA = this.parseCustomDate(a.field_fecha_creacion_art);

          const dateB = this.parseCustomDate(b.field_fecha_creacion_art);

          return dateB - dateA;

        });

      } else if (this.sortOrder === 'oldest') {

        filtered.sort((a, b) => {

          const dateA = this.parseCustomDate(a.field_fecha_creacion_art);

          const dateB = this.parseCustomDate(b.field_fecha_creacion_art);

          return dateA - dateB;

        });

      }



      // Pagination

      const start = (this.currentPage - 1) * this.itemsPerPage;

      return filtered.slice(start, start + this.itemsPerPage);

    },



    totalPages() {

      let filtered = this.items;



      // Filter by category

      if (this.categoryTaxo !== "all") {

        filtered = filtered.filter(item => 

          item.field_categoria_del_articulo_1 === this.categoryTaxo

        );

      }



      // Filter by search query

      if (this.appliedSearchQuery) {

        const searchQuery = this.appliedSearchQuery.toLowerCase();

        filtered = filtered.filter(item => 

          item.title.toLowerCase().includes(searchQuery)

        );

      }



      return Math.ceil(filtered.length / this.itemsPerPage);

    },



    exchangeRates() {

      return {

        COP: 1,



        USD: this.valorUsd,



        EUR: this.valorEur,

      };

    },



    // Filtros activos, generando etiquetas <a>



    activeFilters() {

      let filters = [];



      // Category filter

      if (this.categoryTaxo !== "all") {

        const categoryLabels = {

          "298": "Construcción y remodelación",

          "299": "Estilo de vida",

          "295": "Finca raíz",

          "293": "Hogar"

        };

        filters.push({

          label: `Categoría: ${categoryLabels[this.categoryTaxo] || this.categoryTaxo}`,

          type: "category",

          value: this.categoryTaxo

        });

      }



      // Search filter

      if (this.appliedSearchQuery) {

        filters.push({

          label: `Búsqueda: ${this.appliedSearchQuery}`,

          type: "search",

          value: this.appliedSearchQuery

        });

      }



      // Filtro de ordenamiento

      if (this.sortOrder) {

        const sortLabels = {

          'newest': 'Más reciente',

          'oldest': 'Más antiguo'

        };

        filters.push({

          label: `Orden: ${sortLabels[this.sortOrder]}`,

          type: "sort",

          value: this.sortOrder

        });

      }



      return filters;

    },

  },



  methods: {

    // Método para obtener parámetros de la URL

    getUrlParameter(name) {

      // Crear un objeto URLSearchParams con la query string

      const urlParams = new URLSearchParams(window.location.search);

      

      // Obtener el valor del parámetro

      return urlParams.get(name);

    },

    // Método para parsear fechas en formato DD/MM/YYYY

    parseCustomDate(dateString) {

      // Verificar si la fecha está en el formato correcto

      const [day, month, year] = dateString.split('/').map(Number);

      

      // Crear un nuevo objeto Date (mes es 0-indexed en JavaScript)

      return new Date(year, month - 1, day);

    },

    formatearFechaBlog(fechaString){

      // Dividir la fecha en día, mes y año

      const [dia, mes, anio] = fechaString.split('/');

      

      // Array de nombres de meses en español

      const meses = [

          'Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 

          'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'

      ];

      

      // Convertir a número y restar 1 para el índice del mes

      const mesNumero = parseInt(mes) - 1;

      

      // Formatear la fecha

      return `${meses[mesNumero]} ${dia}, ${anio}`;

    },

    applySearch() {

      this.appliedSearchQuery = this.searchNameProject;



      this.currentPage = 1; // Restablece a la primera página

    },



    async fetchData() {
      this.currentPage = 1;
      const response = await fetch(`/constructora-bolivar-v2/api/blog/all/${this.categoryTaxo}`); // Cambia la URL a tu endpoint

      this.items = await response.json();

    },



    nextPage() {

      if (this.currentPage < this.totalPages) {

        this.currentPage++;

      }

    },



    prevPage() {

      if (this.currentPage > 1) {

        this.currentPage--;

      }

    },



    setPage(page) {

      this.currentPage = page;

    },



    convertCurrency(price) {

      // Convertir el precio a la moneda seleccionada



      if (this.currency === "COP") {

        return price; // Precio en COP

      } else if (this.currency === "USD") {

        return (price * this.exchangeRates.USD).toFixed(0); // Convertir a USD

      } else if (this.currency === "EUR") {

        return (price * this.exchangeRates.EUR).toFixed(0); // Convertir a EUR

      }

    },



    changeCurrency(selectedCurrency) {

      this.currency = selectedCurrency; // Cambiar la moneda



      // Actualizar el icono de la moneda



      if (selectedCurrency === "COP") {

        this.currencyIcon = "/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg";

      } else if (selectedCurrency === "USD") {

        this.currencyIcon = "/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-usd.svg";

      } else if (selectedCurrency === "EUR") {

        this.currencyIcon = "/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-eur.svg";

      }

    },



    async getTrm() {

      const response = await fetch("/constructora-bolivar-v2/api/trm");



      const datrm = await response.json();



      this.valorUsd = datrm[0].field_valor;



      this.valorEur = datrm[1].field_valor;

    },



    async getActuLasts() {

      const response = await fetch(`/constructora-bolivar-v2/api/blog/290/all`);

      this.listActuLasts = await response.json();

    },



    async getNovedaLasts() {

      const response = await fetch(`/constructora-bolivar-v2/api/blog/292/293`);

      this.listNovedaLasts = await response.json();

    },



    async getNotepreLasts() {

      const response = await fetch(`/constructora-bolivar-v2/api/blog/291/all`);

      this.listNotePuedesLasts = await response.json();

    },



    async getDestacLasts() {

      const response = await fetch(`/constructora-bolivar-v2/api/blog/289/all`);

      this.listDestacaLasts = await response.json();

    },

    async getListAriclesInteres(){

      const response = await fetch(`/constructora-bolivar-v2/api/blog/all/${this.categoryTaxoArticle}`);

      let articles = await response.json();

      // Filtrar artículos y limitar a 6

      this.listAriclesInteres = articles

        .filter(article => article.nid !== this.nodeIdArticle)

        .slice(0, 6);

    },

    async getListAriclesRecient() {

      try {

        const response = await fetch(`/constructora-bolivar-v2/api/blog/all/all`);

        let articlesRec = await response.json();



        // Convertir la fecha de "DD/MM/YYYY" a un formato de comparación y ordenar

        articlesRec = articlesRec.sort((a, b) => {

          const dateA = a.field_fecha_creacion_art

            ? new Date(a.field_fecha_creacion_art.split('/').reverse().join('-'))

            : new Date(0);

          const dateB = b.field_fecha_creacion_art

            ? new Date(b.field_fecha_creacion_art.split('/').reverse().join('-'))

            : new Date(0);



          return dateB - dateA; // Ordenar de más reciente a más antiguo

        });



        // Filtrar artículos y limitar a 4

        this.listAriclesRecient = articlesRec

          .filter(article => article.nid !== this.nodeIdArticle)

          .slice(0, 4);

      } catch (error) {

        console.error("Error fetching recent articles:", error);

      }

    },

    applySearch() {

      this.appliedSearchQuery = this.searchNameProject;

      this.currentPage = 1;

    },



    removeFilter(filter) {

      if (filter.type === "category") {

        this.categoryTaxo = "all";

      } else if (filter.type === "search") {

        this.searchNameProject = "";

        this.appliedSearchQuery = "";

      } else if (filter.type === "sort") {

        this.sortOrder = "";

      }

    },



    removeAllFilters() {

      this.categoryTaxo = "all";

      this.searchNameProject = "";

      this.appliedSearchQuery = "";

      this.sortOrder = "";

    },

  

    

  },



  filters: {

    formatPrice(value) {

      //formatear precios



      let val = (value / 1).toFixed(0).replace(".", ",");



      return val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");

    },

  },



  created() {

    this.getTrm();



    const sectorCategoryOne = document.getElementById('sectorCategoryOne');

    if(sectorCategoryOne){

      this.getDestacLasts();

    }

    const sectorCategoryTwo = document.getElementById('sectorCategoryTwo');

    if(sectorCategoryTwo){

      this.getActuLasts();

    }

    const sectorCategoryThree = document.getElementById('sectorCategoryThree');

    if(sectorCategoryThree){

      this.getNovedaLasts();

      this.getNotepreLasts();

    }



    // Capturar valores desde atributos de datos

    const appElement = document.getElementById('categoryId');

    // Obtener categoría

    if(appElement){

      const categoryArticle = appElement.getAttribute('data-categoria');

      const nodeArticle = appElement.getAttribute('data-nodoid');

      if (categoryArticle && nodeArticle) {

        this.categoryTaxoArticle = categoryArticle;

        this.nodeIdArticle = nodeArticle;

      }

      this.getListAriclesInteres();



      this.getListAriclesRecient();

    }



    // Capturar el parámetro de categoría al crear la instancia

    const categoriaParam = this.getUrlParameter('categoria');

    // Si existe el parámetro, actualizar categoryTaxo

    if (categoriaParam) {

      this.categoryTaxo = categoriaParam;

      this.fetchData();

    }

    

  },

  watch: {

    categoryTaxo() {

      this.currentPage = 1;

      this.fetchData();

    }

  },

  mounted() {



    // Inicializar el carrusel despuÃ©s de que los elementos sean renderizados



    this.$nextTick(() => {



      setTimeout(() => {



        //OWL Carousel Blogs



        const owlBlogActuLasts = $('.owl-carousel-news');

        owlBlogActuLasts.owlCarousel('destroy');



        owlBlogActuLasts.owlCarousel({

          loop:false,

          margin:25,

          dots:true,

          responsiveClass:true,

          responsive:{

            0:{

                items:1

            },

            768:{

                items:1,

                nav:false

            },

            1000:{

                items:3,

                nav:true

            }

          }

        });



        owlBlogActuLasts.trigger('refresh.owl.carousel');





        const owlBlogoteLasts = $('.owl-carousel-news-v2');

        owlBlogoteLasts.owlCarousel('destroy');



          owlBlogoteLasts.owlCarousel({

            loop:false,

            margin:25,

            dots:true,

            responsiveClass:true,

            responsive:{

              0:{

                  items:1,
                  nav:false
              },

              768:{

                  items:1,
                  nav:false

              },

              1000:{

                  items:1,
                  nav:true

              }

            }

          });



          owlBlogoteLasts.trigger('refresh.owl.carousel');



      }, 3500);



    });



  }

});

