new Vue({
    delimiters: ["${", "}"],
    el: '#app',
    data() {
      return {
        isShow: false,
        items: [],
        valorUsd: '',
        valorEur: '',
        currentPage: 1,
        itemsPerPage: 12,
        currency: 'COP',
        currencyIcon: '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg',
        currencySymbols: {
            COP: '$',   // Símbolo para COP
            USD: '', // Símbolo para USD
            EUR: '€',   // Símbolo para EUR
        },
        searchNameProject: '',// Término de búsqueda ingresado por el usuario
        appliedSearchQuery: '', // Término aplicado al hacer clic en el botón
        citysTaxo: 'all', // Filtro de ciudad
        listFilterCitys: [],
        selectedSectors: [] // Sectores seleccionados
      };
    },
    computed: {
      filteredItems() {
        const searchQuery = this.appliedSearchQuery.toLowerCase(); // Convertir a minúsculas para búsqueda insensible a mayúsculas

        // Filtrar items según ciudad, tipo de vivienda y estado
        const filtered = this.items.filter(item => {
            const matchesCiudad = this.citysTaxo === 'all' || item.field_ciudad_pl_1 === this.citysTaxo; // Ajusta 'ciudad' según tu estructura de datos
            const matchesSearch = searchQuery === '' || item.title.toLowerCase().includes(searchQuery);

            return matchesCiudad && matchesSearch;
        });

        const start = (this.currentPage - 1) * this.itemsPerPage;
        return filtered.slice(start, start + this.itemsPerPage);
      },
      totalPages() {
        const searchQuery = this.appliedSearchQuery.toLowerCase(); // Convertir a minúsculas para búsqueda insensible a mayúsculas
        const filteredCount = this.items.filter(item => {
            const matchesCiudad = this.citysTaxo === 'all' || item.field_ciudad_pl_1 === this.citysTaxo; // Ajusta 'ciudad'
            const matchesSearch = searchQuery === '' || item.title.toLowerCase().includes(searchQuery);
            return matchesCiudad && matchesSearch;
        }).length;

        return Math.ceil(filteredCount / this.itemsPerPage);
      },
      // Filtros activos, generando etiquetas <a>
      activeFilters() {
        let filters = [];

        // Filtro de Nombre
        if (this.appliedSearchQuery !== '') {
          filters.push({
            label: `Búsqueda: ${this.appliedSearchQuery}`, // Muestra el término de búsqueda
            type: 'search',
            value: this.appliedSearchQuery // Guarda el valor del término aplicado
          });
        }


        // Filtro de Ciudad
        if (this.citysTaxo !== '') {
          const city = this.listFilterCitys.find(city => city.tid === this.citysTaxo);
          if (city) {
            filters.push({
              label: city.name,
              type: 'city',
              value: this.citysTaxo
            });
          }
        }

        return filters;
      },
      exchangeRates() {

        return {

            COP: 1,

            USD: this.valorUsd,

            EUR: this.valorEur

        };

      },

    },

    methods: {
      applySearch() {

        this.appliedSearchQuery = this.searchNameProject;

        this.currentPage = 1; // Restablece a la primera página

      },
      convertCurrency(price) {

          // Convertir el precio a la moneda seleccionada

          if (this.currency === 'COP') {

              return (price); // Precio en COP

          } else if (this.currency === 'USD') {

              return (price * this.exchangeRates.USD).toFixed(0); // Convertir a USD

          } else if (this.currency === 'EUR') {

              return (price * this.exchangeRates.EUR).toFixed(0); // Convertir a EUR

          }

      },

      changeCurrency(selectedCurrency) {

          this.currency = selectedCurrency; // Cambiar la moneda



          // Actualizar el icono de la moneda

          if (selectedCurrency === 'COP') {

              this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg';

          } else if (selectedCurrency === 'USD') {

              this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-usd.svg';

          } else if (selectedCurrency === 'EUR') {

              this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-eur.svg';

          }

      },

      async getTrm() {

        const response = await fetch('/constructora-bolivar-v2/api/trm');

        const datrm = await response.json();

        this.valorUsd = datrm[0].field_valor;

        this.valorEur = datrm[1].field_valor;

      },
      // Eliminar un filtro específico
      removeFilter(filter) {
        if (filter.type === 'city') {
          this.citysTaxo = 'all';
        }else if (filter.type === 'search') {
          this.searchNameProject = '';
          this.appliedSearchQuery = '';
        }

        // Ejecutar la búsqueda con los filtros actualizados
        this.fetchData();
      },
      removeFilterAll(){
        this.selectedSectors = [];

        this.citysTaxo = 'all';

        this.searchNameProject = '';
        this.appliedSearchQuery = '';

        // Ejecutar la búsqueda con los filtros actualizados
        this.fetchData();
      },
      async fetchData() {
        this.currentPage = 1;
        const response = await fetch(`/constructora-bolivar-v2/api/pagos-en-linea/all`);
        this.items = await response.json();
        $('.dropdownCustomFilter .wrapperFilterTargetCity').removeClass('show');
      },
      nextPage() {
          if (this.currentPage < this.totalPages) {
              this.currentPage++;
          }
      },
      prevPage() {
          if (this.currentPage > 1) {
              this.currentPage--;
          }
      },
      setPage(page) {
          this.currentPage = page;
      },
      async getCitysTaxonomies() {
        const response = await fetch('/constructora-bolivar-v2/api/filtro/ciudades');
        const cityData = await response.json();

        // Eliminar las ciudades duplicadas basándose en el nombre
        const uniqueCityData = cityData.filter((value, index, self) => 
          index === self.findIndex((t) => (
            t.name === value.name
          ))
        );

        // Añadimos la propiedad 'isShow' a cada ciudad que recibimos del servicio
        this.listFilterCitys = uniqueCityData.map(city => ({
          ...city,
          isShow: false, // Inicializamos todos los filtros como ocultos
        }));
      }
    },

    filters: {

      formatPrice(value) {

        //formatear precios

        let val = (value / 1).toFixed(0).replace(".", ",");

        return val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");

      },

    },

    created() {

      this.getTrm();
      this.getCitysTaxonomies();
      this.fetchData();

    },

});