new Vue({
    delimiters: ["${", "}"],
    el: '#app',
    data() {
        return {
            isShow: false,
            items: [],
            valorUsd: '',
            valorEur: '',
            currentPage: 1,
            itemsPerPage: 12,
            currency: 'COP',
            currencyIcon: '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg',
            currencySymbols: {
                COP: '$',   // Símbolo para COP
                USD: '', // Símbolo para USD
                EUR: '€',   // Símbolo para EUR
            },
            precioMinimo: 100000000,  // Precio mínimo por defecto
            precioMaximo: 900000000,  // Precio máximo por defecto
            filtroPrecionActivo: false,
            citysTaxo: 'all', // Filtro de ciudad
            sectorsTaxo: 'all', // Filtro de sector
            typeVivienTaxo: 'all', // Filtro de tipo de vivienda
            statusTaxo: 'all', // Filtro de estado
            listFilterCitys: [],
            listFilterTypeVivi: [],
            listFilterStatus: [],
            listFilterSectors: [],
            selectedSectors: [] // Sectores seleccionados
        };
    },
    computed: {
     filteredItems() {
        // Filtrar items según ciudad, tipo de vivienda y estado
        const filtered = this.items.filter(item => {

            const matchesCiudad = this.sectorsTaxo === 'all' || item.field_sector === this.sectorsTaxo; // Ajusta 'ciudad' según tu estructura de datos
            const matchesTipo = this.typeVivienTaxo === 'all' || item.field_tipo_vivienda === this.typeVivienTaxo; // Ajusta 'tipoVivienda'
            const matchesEstado = this.statusTaxo === 'all' || item.field_estados_1 === this.statusTaxo; // Ajusta 'estado'

            // Nuevo filtro de precio
            const precio = parseFloat(item.field_precio);
            const matchesPrecio = !this.filtroPrecionActivo || 
                (precio >= this.precioMinimo && precio <= this.precioMaximo);

            return matchesCiudad && matchesTipo && matchesEstado && matchesPrecio;
        });

        const start = (this.currentPage - 1) * this.itemsPerPage;
        return filtered.slice(start, start + this.itemsPerPage);
      },
      totalPages() {
        const filteredCount = this.items.filter(item => {
            const matchesCiudad = this.sectorsTaxo === 'all' || item.field_sector === this.sectorsTaxo; // Ajusta 'ciudad'
            const matchesTipo = this.typeVivienTaxo === 'all' || item.field_tipo_vivienda === this.typeVivienTaxo; // Ajusta 'tipoVivienda'
            const matchesEstado = this.statusTaxo === 'all' || item.field_estados_1 === this.statusTaxo; // Ajusta 'estado'

            // Nuevo filtro de precio
            const precio = parseFloat(item.field_precio);
            const matchesPrecio = !this.filtroPrecionActivo || 
                (precio >= this.precioMinimo && precio <= this.precioMaximo);

            return matchesCiudad && matchesTipo && matchesEstado && matchesPrecio;
        }).length;

        return Math.ceil(filteredCount / this.itemsPerPage);
      },
      exchangeRates() {
        return {
            COP: 1,
            USD: this.valorUsd,
            EUR: this.valorEur
        };
      },
      // Filtros activos, generando etiquetas <a>
      activeFilters() {
        let filters = [];

        // Filtro de Sector
        if (this.selectedSectors.length > 0) {
            this.selectedSectors.forEach(sectorTid => {
                const sector = this.listFilterSectors.find(s => s.tid === sectorTid);
                if (sector) {
                    filters.push({
                        label: sector.name,
                        type: 'sector',
                        value: sectorTid
                    });
                }
            });
        }

        // Filtro de Tipo de Vivienda
        if (this.typeVivienTaxo !== 'all') {
            const type = this.listFilterTypeVivi.find(type => type.tid === this.typeVivienTaxo);
            if (type) {
                filters.push({
                    label: type.name,
                    type: 'typeVivienda',
                    value: this.typeVivienTaxo
                });
            }
        }

        // Filtro de Estado
        if (this.statusTaxo !== 'all') {
            const status = this.listFilterStatus.find(status => status.tid === this.statusTaxo);
            if (status) {
                filters.push({
                    label: status.name,
                    type: 'status',
                    value: this.statusTaxo
                });
            }
        }

        // Nuevo: Filtro de Precio
        if (this.filtroPrecionActivo) {
          filters.push({
            label: `Precio: ${this.formatPrice(this.precioMinimo)} - ${this.formatPrice(this.precioMaximo)}`,
            type: 'price',
            value: {
                min: this.precioMinimo, 
                max: this.precioMaximo
            }
          });
        }

        return filters;
      }
    },
    methods: {
        // Método para formatear precio (si no lo tienes ya definido)
        formatPrice(value) {
            let val = (value / 1).toFixed(0).replace(".", ",");
            return '$' + val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");
        },
        // Método para aplicar filtro de precio
        aplicarFiltroPrecio() {
            const inputPrecioMinimo = document.getElementById('minPrice');
            const inputPrecioMaximo = document.getElementById('maxPrice');

            this.precioMinimo = parseFloat(inputPrecioMinimo.value) || 100000000;
            this.precioMaximo = parseFloat(inputPrecioMaximo.value) || 900000000;

            // Validar que el precio mínimo no sea mayor que el máximo
            if (this.precioMinimo > this.precioMaximo) {
                [this.precioMinimo, this.precioMaximo] = [this.precioMaximo, this.precioMinimo];
            }

            // Activar filtro de precio
            this.filtroPrecionActivo = true;

            // Cargar datos con nuevos filtros
            this.fetchData();

            // Cerrar dropdown
            $('.dropdownCustomFilter .wrapperFilterTargetPrice').removeClass('show');
        },

        // Método para limpiar filtro de precio
        limpiarFiltroPrecio() {
            // Restablecer valores de precio
            this.precioMinimo = 100000000;
            this.precioMaximo = 900000000;
            this.filtroPrecionActivo = false;

            // Restablecer campos de entrada
            const inputPrecioMinimo = document.getElementById('minPrice');
            const inputPrecioMaximo = document.getElementById('maxPrice');
            inputPrecioMinimo.value = this.precioMinimo;
            inputPrecioMaximo.value = this.precioMaximo;

            // Cargar datos sin filtro de precio
            this.fetchData();

            $('.dropdownCustomFilter .wrapperFilterTargetPrice').removeClass('show');
        },
        toggleShow(index) {
          // Alterna el estado de visibilidad para el filtro de la ciudad correspondiente
          this.listFilterCitys[index].isShow = !this.listFilterCitys[index].isShow;
        },
        clearFiltersCitySectors() {
          // Restablece todos los filtros a sus valores iniciales
          this.sectorsTaxo = 'all';
          this.selectedSectors = [];

          // Opcional: actualiza los datos
          this.fetchData();
        },
        // Eliminar un filtro específico
        removeFilter(filter) {
          if (filter.type === 'city') {
              this.citysTaxo = 'all';
          } else if (filter.type === 'sector') {
              this.selectedSectors = this.selectedSectors.filter(tid => tid !== filter.value);
          } else if (filter.type === 'typeVivienda') {
              this.typeVivienTaxo = 'all';
          } else if (filter.type === 'status') {
              this.statusTaxo = 'all';
          }else if (filter.type === 'price') {
            this.limpiarFiltroPrecio();
          }

          // Ejecutar la búsqueda con los filtros actualizados
          this.fetchData();
        },
        removeFilterAll(){
          this.sectorsTaxo = 'all';
          this.selectedSectors = [];

          this.citysTaxo = 'all';
          this.typeVivienTaxo = 'all';
          this.statusTaxo = 'all';

          // Lógica existente de restablecimiento
          this.limpiarFiltroPrecio();

          // Ejecutar la búsqueda con los filtros actualizados
          this.fetchData();
        },
        async fetchData() {
          this.currentPage = 1;
          const sectorsTaxoSelectors = this.selectedSectors.length ? this.selectedSectors.join(",") : "all";

          const response = await fetch(`/constructora-bolivar-v2/api/proyectos-vivienda-vendidos/all/${sectorsTaxoSelectors}/${this.typeVivienTaxo}/7`); // Cambia la URL a tu endpoint
          this.items = await response.json();

          $('.dropdownCustomFilter .wrapperFilterTargetCity').removeClass('show');
        },
        // Método que se llama cuando cambian las selecciones de checkbox
        handleSectorChange() {
            // Ejecutar fetchData directamente cuando cambia la selección
            this.fetchData();
        },
        nextPage() {
            if (this.currentPage < this.totalPages) {
                this.currentPage++;
            }
        },
        prevPage() {
            if (this.currentPage > 1) {
                this.currentPage--;
            }
        },
        setPage(page) {
            this.currentPage = page;
        },
        convertCurrency(price) {
            // Convertir el precio a la moneda seleccionada
            if (this.currency === 'COP') {
                return (price); // Precio en COP
            } else if (this.currency === 'USD') {
                return (price * this.exchangeRates.USD).toFixed(0); // Convertir a USD
            } else if (this.currency === 'EUR') {
                return (price * this.exchangeRates.EUR).toFixed(0); // Convertir a EUR
            }
        },
        changeCurrency(selectedCurrency) {
            this.currency = selectedCurrency; // Cambiar la moneda

            // Actualizar el icono de la moneda
            if (selectedCurrency === 'COP') {
                this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg';
            } else if (selectedCurrency === 'USD') {
                this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-usd.svg';
            } else if (selectedCurrency === 'EUR') {
                this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-eur.svg';
            }
        },
        // Filtra los sectores por ciudad
        getSectoresByCiudad(tidCiudad) {
          return this.listFilterSectors.filter(sector => sector.field_ciudad === tidCiudad);
        },
        // Marca o desmarca todos los sectores de una ciudad
        toggleAllSectors(tidCiudad) {
          const sectoresCiudad = this.getSectoresByCiudad(tidCiudad).map(sector => sector.tid);

          // Verifica si todos los sectores ya están seleccionados
          const allSelected = sectoresCiudad.every(tid => this.selectedSectors.includes(tid));

          if (allSelected) {
            // Si todos están seleccionados, los desmarca
            this.selectedSectors = this.selectedSectors.filter(tid => !sectoresCiudad.includes(tid));
          } else {
            // Si no todos están seleccionados, los marca
            this.selectedSectors = [
              ...this.selectedSectors,
              ...sectoresCiudad.filter(tid => !this.selectedSectors.includes(tid))
            ];
          }

          // Aplicar filtro automáticamente
          this.fetchData();
        },
        async getTrm() {
          const response = await fetch('/constructora-bolivar-v2/api/trm');
          const datrm = await response.json();
          this.valorUsd = datrm[0].field_valor;
          this.valorEur = datrm[1].field_valor;
        },
        async getTypeViviTaxonomies() {
          const response = await fetch('/constructora-bolivar-v2/api/filtro/tipo-vivienda');
          this.listFilterTypeVivi = await response.json();
        },
        async getStatusTaxonomies() {
          const response = await fetch('/constructora-bolivar-v2/api/filtro/estados');
          this.listFilterStatus = await response.json();
        },
        async getCitysTaxonomies() {
          const response = await fetch('/constructora-bolivar-v2/api/filtro/ciudades');
          const cityData = await response.json();

          // Eliminar las ciudades duplicadas basándose en el nombre
          const uniqueCityData = cityData.filter((value, index, self) => 
            index === self.findIndex((t) => (
              t.name === value.name
            ))
          );

          // Añadimos la propiedad 'isShow' a cada ciudad que recibimos del servicio
          this.listFilterCitys = uniqueCityData.map(city => ({
            ...city,
            isShow: false, // Inicializamos todos los filtros como ocultos
          }));
        },
        async getSectorsTaxonomies() {
          const response = await fetch('/constructora-bolivar-v2/api/filtro/sectores');
          this.listFilterSectors = await response.json();
        }
    },
    filters: {
      formatPrice(value) {
        //formatear precios
        let val = (value / 1).toFixed(0).replace(".", ",");
        return val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");
      },
    },
    watch: {
        // Observador para selectedSectors
        selectedSectors: {
            handler(newVal, oldVal) {
                // Si hay cambios reales en la selección (no solo ordenación interna)
                if (newVal.length !== oldVal.length || 
                    newVal.some(item => !oldVal.includes(item)) || 
                    oldVal.some(item => !newVal.includes(item))) {
                    
                    // Opcional: agregamos un pequeño retraso para evitar múltiples llamadas
                    // si el usuario está seleccionando rápidamente varios checkboxes
                    if (this.debounceTimer) {
                        clearTimeout(this.debounceTimer);
                    }
                    
                    this.debounceTimer = setTimeout(() => {
                        this.handleSectorChange();
                    }, 300); // 300ms de retraso
                }
            },
            deep: true
        }
    },
    created() {
      this.getTrm();
      this.getTypeViviTaxonomies();
      // this.getStatusTaxonomies();
      this.getCitysTaxonomies();
      this.getSectorsTaxonomies();
      
      this.fetchData();
    },
});