new Vue({

    delimiters: ["${", "}"],

    el: '#app',

    data() {

        return {

            items: [],

            valorUsd: '',

            valorEur: '',

            messageSMMLV: '',

            currency: 'COP',

            currencyIcon: '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg',

            currencySymbols: {

                COP: '$',   // Símbolo para COP

                USD: '', // Símbolo para USD

                EUR: '€',   // Símbolo para EUR

            },

            listProjectsLasts: [],
            listProjectsAsso: [],
            citySingleProject: "",
            nodeIdSingleProject: "",
            price: 0 // Precio inicial del nodo

        };

    },

    computed: {

      exchangeRates() {

        return {

            COP: 1,

            USD: this.valorUsd,

            EUR: this.valorEur

        };

      },

      convertedPrice() {

        const price = this.price;

        const rate = this.exchangeRates[this.currency];
        return this.formatPrice(price * rate);

      },

      messageSMMLV(){

        return this.messageSMMLV;

      }

    },

    methods: {

      handleCotizarClick(event) {

        localStorage.removeItem('projectSimulador');

        // Capturar el elemento donde se hizo clic

        const target = event.currentTarget;



        // Crear un objeto con los datos

        const proyectoData = {

            title: target.dataset.title,

            priceSeparation: target.dataset.priceseparator,

            city: target.dataset.city,

            alcobasCard: target.dataset.alcobascard,

            banosCard: target.dataset.banoscard,

            salacomedorCard: target.dataset.salacomedorcard,

            areaCard: target.dataset.areacard,

            img: target.dataset.img,

            price: target.dataset.price,

            plazoCuotaIni: target.dataset.plazocuotaini,
            listTypesApto: target.dataset.jsontypeaptos,
            codeSerk: target.dataset.codeserk

        };



        // Convertir el objeto a JSON y guardarlo en localStorage

        localStorage.setItem('projectSimulador', JSON.stringify(proyectoData));



        // Redirigir al usuario a la página /simulacion-cuota

        window.location.href = '/constructora-bolivar-v2/simulador-cuota-inicial';

      },

      convertCurrency(price) {

        // Convertir el precio a la moneda seleccionada

        if (this.currency === 'COP') {

            return (price); // Precio en COP

        } else if (this.currency === 'USD') {

            return (price * this.exchangeRates.USD).toFixed(0); // Convertir a USD

        } else if (this.currency === 'EUR') {

            return (price * this.exchangeRates.EUR).toFixed(0); // Convertir a EUR

        }

      },

      changeCurrency(selectedCurrency) {

        this.currency = selectedCurrency; // Cambiar la moneda



        // Actualizar el icono de la moneda

        if (selectedCurrency === 'COP') {

            this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-cop.svg';

        } else if (selectedCurrency === 'USD') {

            this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-usd.svg';

        } else if (selectedCurrency === 'EUR') {

            this.currencyIcon = '/constructora-bolivar-v2/themes/custom/constructorabolivar/assets/header/icono-money-eur.svg';

        }

      },

      async getTrm() {

        const response = await fetch('/constructora-bolivar-v2/api/trm');

        const datrm = await response.json();

        this.valorUsd = datrm[0].field_valor;

        this.valorEur = datrm[1].field_valor;

        this.messageSMMLV = datrm[2].description__value;

      },

      formatPrice(value) {

        return value.toLocaleString('es-CO', {

            style: 'currency',

            currency: this.currency,

            minimumFractionDigits: 0,

            maximumFractionDigits: 0

        });

      },

      async getListsProjectsAsso() {

        try {

          const response = await fetch(`/constructora-bolivar-v2/api/proyectos-vivienda/${this.citySingleProject}/all/all/6`);

          let projecAsso = await response.json();


          // Filtrar proyecto y limitar a 4

          this.listProjectsAsso = projecAsso

            .filter(project => project.nid !== this.nodeIdProject)

            .slice(0, 6);

        } catch (error) {

          console.error("Error fetching recent project:", error);

        }

      }

    },

    filters: {

      formatPrice(value) {

        //formatear precios

        let val = (value / 1).toFixed(0).replace(".", ",");

        return val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");

      },

    },

    created() {

      this.price = parseFloat(document.querySelector('.wrapperPriceContent').dataset.price);

      this.getTrm();

      // Capturar valores desde atributos de datos
      const appElement = document.getElementById('idNodeTwo');

      // Obtener categoría
      if(appElement){
        const cityProject = appElement.getAttribute('data-city');
        const nodeProject = appElement.getAttribute('data-nodoid');
        if (cityProject && nodeProject) {
          this.citySingleProject = cityProject;
          this.nodeIdSingleProject = nodeProject;
          console.log(this.citySingleProject, this.nodeIdSingleProject);
          this.getListsProjectsAsso();
        }

      
      }
    },

    mounted() {



    // Inicializar el carrusel despuÃ©s de que los elementos sean renderizados



    this.$nextTick(() => {



      setTimeout(() => {



        //OWL Carousel Blogs



        const owlProjectAsso = $('.owl-carousel-projects');

        owlProjectAsso.owlCarousel('destroy');



        owlProjectAsso.owlCarousel({

          loop:false,

          margin:30,

          nav:false,

          responsiveClass:true,

          responsive:{

              0:{

                  items:1,
                  dots:true

              },

              768:{

                  items:1,
                  dots:true

              },

              1000:{

                  items:3,
                  dots:true

              }

          }

        });



        owlProjectAsso.trigger('refresh.owl.carousel');

      }, 3500);



    });



  }

});